
/* Generated data (by glib-mkenums) */

#ifndef EPHY_TYPE_BUILTINS_H
#define EPHY_TYPE_BUILTINS_H 1

#include <glib-object.h>

G_BEGIN_DECLS


/* --- ephy-link.h --- */
#define EPHY_TYPE_LINK_FLAGS ephy_link_flags_get_type()
GType ephy_link_flags_get_type (void);

/* --- ephy-shell.h --- */
#define EPHY_TYPE_SHELL_ERROR ephy_shell_error_get_type()
GType ephy_shell_error_get_type (void);
#define EPHY_TYPE_SHELL_STARTUP_FLAGS ephy_shell_startup_flags_get_type()
GType ephy_shell_startup_flags_get_type (void);
#define EPHY_TYPE_NEW_TAB_FLAGS ephy_new_tab_flags_get_type()
GType ephy_new_tab_flags_get_type (void);

/* --- ephy-tab.h --- */
#define EPHY_TYPE_TAB_NAVIGATION_FLAGS ephy_tab_navigation_flags_get_type()
GType ephy_tab_navigation_flags_get_type (void);
#define EPHY_TYPE_TAB_ADDRESS_EXPIRE ephy_tab_address_expire_get_type()
GType ephy_tab_address_expire_get_type (void);

/* --- ephy-navigation-action.h --- */
#define EPHY_TYPE_NAVIGATION_DIRECTION ephy_navigation_direction_get_type()
GType ephy_navigation_direction_get_type (void);
G_END_DECLS

#endif /* EPHY_TYPE_BUILTINS_H */

/* Generated data ends here */

